@@ -25,21 +25,11 @@
 #include <QScriptValue>
 #include <KDoubleNumInput>
 #include <KGlobal>
+#include <KLocale>
 
 
-QString FloatDataInformation::valueString() const
-{
-    if (!mWasAbleToRead)
-        return i18nc("invalid value (out of range)", "&lt;invalid&gt;");
-    return valueString(mValue);
-}
 
-QWidget* FloatDataInformation::createEditWidget(QWidget* parent) const
-{
-    return staticCreateEditWidget(parent);
-}
-
-QWidget* FloatDataInformation::staticCreateEditWidget(QWidget* parent)
+QWidget* FloatDataInformationMethods::staticCreateEditWidget(QWidget* parent)
 {
     KDoubleNumInput* ret = new KDoubleNumInput(parent);
     ret->setMinimum(std::numeric_limits<float>::min());
@@ -47,32 +37,16 @@ QWidget* FloatDataInformation::staticCreateEditWidget(QWidget* parent)
     return ret;
 }
 
-QVariant FloatDataInformation::dataFromWidget(const QWidget* w) const
-{
-    return staticDataFromWidget(w);
-}
-
-QVariant FloatDataInformation::staticDataFromWidget(const QWidget* w)
+QVariant FloatDataInformationMethods::staticDataFromWidget(const QWidget* w)
 {
     const KDoubleNumInput* spin = dynamic_cast<const KDoubleNumInput*> (w);
     Q_CHECK_PTR(spin);
     if (spin)
-    {
-#if QT_VERSION >= 0x040600
         return ((float) spin->value());
-#else
-        return spin->value();
-#endif
-    }
     return QVariant();
 }
 
-void FloatDataInformation::setWidgetData(QWidget* w) const
-{
-    staticSetWidgetData(mValue, w);
-}
-
-void FloatDataInformation::staticSetWidgetData(float value, QWidget* w)
+void FloatDataInformationMethods::staticSetWidgetData(float value, QWidget* w)
 {
     KDoubleNumInput* spin = dynamic_cast<KDoubleNumInput*> (w);
     Q_CHECK_PTR(spin);
@@ -80,34 +54,14 @@ void FloatDataInformation::staticSetWidgetData(float value, QWidget* w)
         spin->setValue(value);
 }
 
-AllPrimitiveTypes FloatDataInformation::qVariantToAllPrimitiveTypes(const QVariant& value) const
-{
-    return AllPrimitiveTypes(value.toFloat());
-}
-
-AllPrimitiveTypes FloatDataInformation::value() const
-{
-    return AllPrimitiveTypes(mValue);
-}
-
-void FloatDataInformation::setValue(AllPrimitiveTypes newVal)
-{
-    mValue = newVal.floatValue;
-}
-
-QScriptValue FloatDataInformation::asScriptValue(float value, QScriptEngine* engine, ScriptHandlerInfo* handler)
+QScriptValue FloatDataInformationMethods::asScriptValue(float value, QScriptEngine* engine, ScriptHandlerInfo* handler)
 {
     Q_UNUSED(engine);
     Q_UNUSED(handler);
     return QScriptValue(value);
 }
 
-QScriptValue FloatDataInformation::valueAsQScriptValue() const
-{
-    return asScriptValue(mValue, 0, 0);
-}
-
-QString FloatDataInformation::valueString(float value)
+QString FloatDataInformationMethods::staticValueString(float value)
 {
 	if (Kasten2::StructViewPreferences::localeAwareFloatFormatting())
 		return KGlobal::locale()->formatNumber(value, Kasten2::StructViewPreferences::floatPrecision());
