@@ -26,6 +26,7 @@
 #define STRINGDATAINFORMATION_H
 
 #include "../datainformation.h"
+#include "../dummydatainformation.h"
 #include "stringdata.h"
 
 class DummyDataInformation;
@@ -35,20 +36,16 @@ const QLatin1String stringEncodings[] = {
     QLatin1String("utf-16-be"), QLatin1String("utf32-le"), QLatin1String("utf32-be")
 };
 
-class StringDataInformation : public DataInformation
+class StringDataInformation : public DataInformationWithDummyChildren
 {
-protected:
-    virtual BitCount32 offset(unsigned int index) const;
-    StringDataInformation(const StringDataInformation&);
+    DATAINFORMATION_CLONE_DECL(StringDataInformation, DataInformationWithDummyChildren);
 public:
     enum StringType {
         InvalidEncoding = -1, ASCII = 0, Latin1, UTF8, UTF16_LE, UTF16_BE, UTF32_LE, UTF32_BE
     };
 
     StringDataInformation(const QString& name, StringType encoding, DataInformationBase* parent = 0);
-    StringDataInformation(const QString& name, QString encoding, DataInformationBase* parent = 0);
     virtual ~StringDataInformation();
-    DATAINFORMATION_CLONE(String)
 
     virtual bool canHaveChildren() const;
     virtual DataInformation* childAt(unsigned int) const;
@@ -73,30 +70,36 @@ public:
     virtual QVariant childData(int row, int column, int role) const;
     virtual Qt::ItemFlags childFlags(int row, int column, bool fileLoaded = true) const;
     virtual BitCount32 childSize(uint index) const;
+    virtual QString childTypeName(uint index) const;
+    virtual void setChildWidgetData(uint index, QWidget* w) const;
+    virtual QVariant dataFromChildWidget(uint index, const QWidget* w) const;
+    virtual QWidget* createChildEditWidget(uint index, QWidget* parent) const;
+    virtual QScriptValue childToScriptValue(uint index, QScriptEngine* engine, ScriptHandlerInfo* handlerInfo) const;
+    virtual BitCount64 childPosition(const DataInformation* child, Okteta::Address start) const;
 
     virtual QString valueString() const;
-    virtual QScriptValue toScriptValue(QScriptEngine* engine, ScriptHandlerInfo* handlerInfo);
 
     StringType encoding() const;
-    void setEncoding(QString encoding);
     void setEncoding(StringType encoding);
-    DummyDataInformation* dummy() const;
     uint terminationCodePoint() const;
     void setTerminationCodePoint(uint term);
-    void setTerminationCodePoint(const QScriptValue& value, QScriptEngine* engine);
     uint maxCharCount() const;
     void setMaxCharCount(uint count);
-    void setMaxCharCount(const QScriptValue& value, QScriptEngine* engine);
     uint maxByteCount() const;
     void setMaxByteCount(uint count);
-    void setMaxByteCount(const QScriptValue& value, QScriptEngine* engine);
     int stringLength() const;
     int stringByteLength() const;
     uint terminationMode() const;
     QString valueAt(int index) const;
+    /** Removes this mode from the termination modes. If none is left, changes string to null terminated
+     * @param mode The mode to remove
+     */
+    void unsetTerminationMode(StringData::TerminationMode mode);
+protected:
+    virtual QScriptClass* scriptClass(ScriptHandlerInfo* handlerInfo) const;
 private:
-    DummyDataInformation* mDummy;
-    StringData* mData;
+    QScopedPointer<DummyDataInformation> mDummy;
+    QScopedPointer<StringData> mData;
     StringType mEncoding;
 };
 
@@ -105,11 +108,6 @@ inline bool StringDataInformation::canHaveChildren() const
     return true;
 }
 
-inline DummyDataInformation* StringDataInformation::dummy() const
-{
-    return mDummy;
-}
-
 inline StringDataInformation::StringType StringDataInformation::encoding() const
 {
     return mEncoding;
