@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2009                                               *
+ *   copyright (C) 2003-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -39,7 +39,7 @@ public:
         table
     };
 
-    explicit UMLArtifact(const QString & name = QString(), Uml::IDType id = Uml::id_None);
+    explicit UMLArtifact(const QString & name = QString(), Uml::ID::Type id = Uml::ID::None);
     virtual ~UMLArtifact();
 
     virtual UMLObject* clone() const;
