@@ -55,6 +55,8 @@ public:
                   Uml::ID::Type id = Uml::ID::None);
     virtual ~MessageWidget();
 
+    virtual void setY(UMLSceneValue y);
+
     //---------- LinkWidget Interface methods implemementation from now on.
 
     virtual void lwSetFont (QFont font);
@@ -90,6 +92,8 @@ public:
     ObjectWidget* objectWidget(Uml::RoleType::Enum role);
     void setObjectWidget(ObjectWidget * ow, Uml::RoleType::Enum role) ;
 
+    bool isSelf() const;
+
     /**
      * Returns the text widget it is related to.
      *
