@@ -153,7 +153,7 @@ QString WidgetBase::documentation() const
  * @param doc   The documentation to be set in the UMLObject
  *              (if m_umlObject is set.)
  */
-void WidgetBase::setDocumentation( const QString &doc )
+void WidgetBase::setDocumentation(const QString& doc)
 {
     if (m_umlObject)
         m_umlObject->setDoc( doc );
@@ -467,13 +467,41 @@ WidgetBase& WidgetBase::operator=(const WidgetBase& other)
     return *this;
 }
 
+/**
+ * return drawing rectangle of widget in local coordinates
+ */
+QRectF WidgetBase::rect() const
+{
+    return m_rect;
+}
+
+/**
+ * set widget rectangle in item coordinates
+ */
+void WidgetBase::setRect(const QRectF& rect)
+{
+    if (m_rect == rect)
+        return;
+    prepareGeometryChange();
+    m_rect = rect;
+    update();
+}
+
+/**
+ * set widget rectangle in item coordinates
+ */
+void WidgetBase::setRect(qreal x, qreal y, qreal width, qreal height)
+{
+    setRect(QRectF(x, y, width, height));
+}
+
 /**
  * @return The bounding rectangle for this widget.
- * @see setBoundingRect
+ * @see setRect
  */
 QRectF WidgetBase::boundingRect() const
 {
-    return m_boundingRect;
+    return m_rect;
 }
 
 /**
